==> ttyrpld-2.03.5.tar.bz2: ttyrpld-2.03.5/doc/support.php <==
<?php include_once("_header.php"); ?>
  <tr>

    <td align="right" valign="top" class="section"><b>Hosters&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge is the primary hoster of the <i>ttyrpld</i>
      project. It runs the File Release System, Support Trackers, Forum, News
      and Mailing Lists systems for us.</p>

      <p class="block">Savannah was the former central for <i>ttyrpld</i>. You
      might find some bugs and feature requests in the trackers over there. 
      However, it still serves as a reference point, so you are free to choose
      between either SourceForge or Savannah if making a tracker entry.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Trackers&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge Links: <a
      href="http://sourceforge.net/projects/ttyrpld/"
      target="_blank">[Overview]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686264"
      target="_blank">[Support]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&amp;atid=686263"
      target="_blank">[Bugs]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686265"
      target="_blank">[Patches]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686266"
      target="_blank">[Feature Requests]</a></p>

      <p class="block">Savannah Links: <a
      href="http://savannah.nongnu.org/projects/ttyrpld/"
      target="_blank">[Overview]</a> <a
      href="http://savannah.nongnu.org/support/?group=ttyrpld"
      target="_blank">[Support]</a> <a
      href="http://savannah.nongnu.org/bugs/?group=ttyrpld"
      target="_blanK">[Bugs]</a>.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Interactive
    help&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">Besides the trackers, which are as slow as e-mail (and
      in fact, <b>IS</b> at that speed, because we get notified of it... <b>by
      e-mail</b>), there is an IRC channel <tt>#ttyrpld</tt> on
      <tt>irc.freenode.net</tt>. It allows for faster replying to questions and
      re-replying to answers and does not take up too much of Savannah's space
      <tt>;-)</tt>. Though, if it is a bug report, <i>also</i> put it on the
      bug tracker for, well, tracking purposes (i.e. "for the record").</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Mailing
    lists&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block"><i>"There's more than one way to do it..."</i>, so here
      is the 3rd option of getting in contact: <a
      href="http://sourceforge.net/mail/?group_id=120202"
      target="_blank">Mailing lists</a>.</p>

      <p class="block">There is currently one list set up, <a
      href="http://lists.sourceforge.net/mailman/listinfo/ttyrpld-user"
      target="_blank">ttyrpld-user</a> which is about everything around
      <i>ttyrpld</i>. Another one, <tt>ttyrpld-devel</tt>, might be created
      when activity rises on the project.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>

==> ttyrpld-2.10.tar.bz2: ttyrpld-2.10/doc/support.php <==
<?php include_once("_header.php"); ?>
  <tr>

    <td align="right" valign="top" class="section"><b>Hosters&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge is the primary hoster of the <i>ttyrpld</i>
      project. It runs the File Release System, Support Trackers, Forum, News
      and Mailing Lists systems for us.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Trackers&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge Links: <a
      href="http://sourceforge.net/projects/ttyrpld/"
      target="_blank">[Overview]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686264"
      target="_blank">[Support]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&amp;atid=686263"
      target="_blank">[Bugs]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686265"
      target="_blank">[Patches]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686266"
      target="_blank">[Feature Requests]</a></p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Interactive
    help&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">There is an IRC channel <tt>#ttyrpld</tt> on
      <tt>irc.freenode.net</tt>. It allows for faster replying to questions and
      re-replying to answers. Of course, only as long as we are online.  If it
      is a bug report, <i>please</i> put it on the bug tracker for archiving
      purposes.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Mailing
    lists&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block"><i>"There's more than one way to do it..."</i>, so here
      is the 3rd option of getting in contact: <a
      href="http://sourceforge.net/mail/?group_id=120202"
      target="_blank">Mailing lists</a>.</p>

      <p class="block">There is currently one list set up, <a
      href="http://lists.sourceforge.net/mailman/listinfo/ttyrpld-user"
      target="_blank">ttyrpld-user</a> which is about everything around
      <i>ttyrpld</i>.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>
